Module gui

Module gui 

Enums

GuiAction
Show main menu for GUI mode - returns the selected action

Functions

get_gui_tool
get_prefix_name_gui
Show a GUI to get a name for a new prefix
prompt_filesystem_access
select_custom_prefix_gui
Show a GUI to select from existing custom prefixes
select_prefix_location_gui
Show a GUI to select a directory for the new prefix
select_proton_with_gui
Show a GUI to select a Proton version from available installations
select_steam_app_with_gui
select_steam_installation
select_steam_library_paths
Prompt user to add additional Steam library paths via GUI. Returns a vector of paths the user selected.
select_verb_category_gui
Show a category selection menu first, then verbs in that category
select_verbs_with_gui
Show a GUI to select verbs to run. Returns list of selected verb names.
show_main_menu_gui
show_text_dialog