Enums
- GuiAction
- Show main menu for GUI mode - returns the selected action
Functions
- get_
gui_ tool - get_
prefix_ name_ gui - Show a GUI to get a name for a new prefix
- prompt_
filesystem_ access - select_
custom_ prefix_ gui - Show a GUI to select from existing custom prefixes
- select_
prefix_ location_ gui - Show a GUI to select a directory for the new prefix
- select_
proton_ with_ gui - Show a GUI to select a Proton version from available installations
- select_
steam_ app_ with_ gui - select_
steam_ installation - select_
steam_ library_ paths - Prompt user to add additional Steam library paths via GUI. Returns a vector of paths the user selected.
- select_
verb_ category_ gui - Show a category selection menu first, then verbs in that category
- select_
verbs_ with_ gui - Show a GUI to select verbs to run. Returns list of selected verb names.
- show_
main_ menu_ gui - show_
text_ dialog